""" setup of {project_desc}. """
# noinspection PyUnresolvedReferences
import sys
print(f"SetUp {{__name__=}} {{sys.executable=}} {{sys.argv=}} {{sys.path=}}")

# noinspection PyUnresolvedReferences
import setuptools

# ReplaceWith#(setup_kwargs = {setup_kwargs_literal(setup_kwargs)})#

if __name__ == "__main__":
    # ReplaceWith#(setuptools.setup(**setup_kwargs))#
    pass



"""
outsourced Python project files templates
=========================================

this package provides generic templates of basic project files for all types of Python projects. this includes project
configuration files like e.g. `.gitignore`, as well as generic project documentation files like `CONTRIBUTING.rst` or
`LICENSE.md`.
"""

__version__ = '0.3.62'
